.ext-ux-livegrid-drop-waiting{background-image:url(../images/loading.gif)!important;}.ext-ux-livegrid.ext-el-mask{z-index:0;}.ext-ux-livegrid .liveScroller{z-index:1;background:none!important;position:absolute;height:3px;right:0;width:18px;overflow:scroll;overflow-x:hidden;}.ext-ux-livegrid .liveScroller div{background:none;width:1px;overflow:hidden;font-size:1px;height:0;}